[cairo-commit]
pycairo/examples/cairo_snippets snippets_gtk.py, 1.3, 1.4
Steve Chaplin
commit at pdx.freedesktop.org
Thu Apr 14 20:25:39 PDT 2005
- Previous message: [cairo-commit] pycairo/cairo pycairo-context.c, 1.35,
1.36 pycairo-pattern.c, 1.14, 1.15
- Next message: [cairo-commit] pycairo/examples context-subclass.py, 1.3,
1.4 gradient.py, 1.4, 1.5 hering.py, 1.4, 1.5 spiral.py, 1.2,
1.3 warpedtext.py, 1.7, 1.8
- Messages sorted by:
[ date ]
[ thread ]
[ subject ]
[ author ]
Committed by: stevech1097
Update of /cvs/cairo/pycairo/examples/cairo_snippets
In directory gabe:/tmp/cvs-serv26442/examples/cairo_snippets
Modified Files:
snippets_gtk.py
Log Message:
SC 2005/04/15
Index: snippets_gtk.py
===================================================================
RCS file: /cvs/cairo/pycairo/examples/cairo_snippets/snippets_gtk.py,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- snippets_gtk.py 7 Apr 2005 02:09:57 -0000 1.3
+++ snippets_gtk.py 15 Apr 2005 03:25:37 -0000 1.4
@@ -92,10 +92,10 @@
cr = self.ctx # used by snippet
# set window bg
- cr.set_rgb_color (*self._bg_rgb)
+ cr.set_source_rgb (*self._bg_rgb)
cr.rectangle(0, 0, width, height)
cr.fill()
cr.set_rgb_color (0,0,0) # reset black
exec (self.snippet_str, globals(), locals())
- Previous message: [cairo-commit] pycairo/cairo pycairo-context.c, 1.35,
1.36 pycairo-pattern.c, 1.14, 1.15
- Next message: [cairo-commit] pycairo/examples context-subclass.py, 1.3,
1.4 gradient.py, 1.4, 1.5 hering.py, 1.4, 1.5 spiral.py, 1.2,
1.3 warpedtext.py, 1.7, 1.8
- Messages sorted by:
[ date ]
[ thread ]
[ subject ]
@@ -92,10 +92,10 @@
cr.rectangle(0, 0, width, height)
cr.fill()
- cr.set_rgb_color (0,0,0) # reset black
+ cr.set_source_rgb (0,0,0) # reset black
exec (self.snippet_str, globals(), locals())
[ author ]
More information about the cairo-commit
mailing list